@@ -6,7 +6,7 @@
 .onAttach <- function(libname, pkgname)
 {
     msg <- styletext(styletext(paste("\nEGAnet (version ", packageVersion("EGAnet"), ")", sep = ""), defaults = "underline"), defaults = "bold")
-    msg <- paste(msg,'\nFor help getting started, type browseVignettes("EGAnet")\n')
+    msg <- paste(msg,'\nCheck out what\'s changed: <https://tinyurl.com/EGAnet-changes>\n')
     msg <- paste(msg,"\nFor bugs and errors, submit an issue to <https://github.com/hfgolino/EGAnet/issues>")
 
     packageStartupMessage(msg)
